@@ -5,6 +5,8 @@ from playwright.sync_api import Page
 from .fun_base import log, send_exception
 from .time_utils import get_current_datetime
 
+import inspect
+
 def fetch(page: Page, url: str, params: Optional[Union[dict, list, str]] = None, headers: Optional[dict] = None, config:
 Optional[dict] = None) -> dict:
     """
@@ -143,3 +145,56 @@ def full_screen_shot(web_page: Page, config):
     full_screenshot_image_path = f'{config.auto_dir}/screenshot/{get_current_datetime()}.png'
     web_page.screenshot(path=full_screenshot_image_path, full_page=True)
     return full_screenshot_image_path
+
+def fetch_get(page: Page, url: str, headers: Optional[dict] = None, config: Optional[dict] = None) -> dict:
+    """
+    发送 HTTP GET 请求，支持自定义 headers 和配置。
+    
+    :param page: Playwright 的 Page 对象
+    :param url: 请求地址
+    :param headers: 自定义 headers 字典
+    :param config: 请求配置字典，可包含 credentials, mode, referrer, referrerPolicy 等
+    :return: 服务器返回的 JSON 响应（dict）
+    """
+    if headers is not None and not isinstance(headers, dict):
+        raise ValueError("headers 参数必须是 dict 或 None")
+    if config is not None and not isinstance(config, dict):
+        raise ValueError("config 参数必须是 dict 或 None")
+
+    try:
+        page.wait_for_load_state('load')
+        response = page.evaluate("""
+            async ({ url, extraHeaders, config }) => {
+                try {
+                    const defaultHeaders = {
+                        'user-agent': 'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/130.0.0.0 Safari/537.36',
+                    };
+
+                    const defaultConfig = {
+                        method: 'GET',
+                        credentials: 'include',
+                        mode: 'cors'
+                    };
+
+                    const headers = Object.assign({}, defaultHeaders, extraHeaders || {});
+                    const options = Object.assign({}, defaultConfig, config || {}, { headers: headers });
+
+                    const response = await fetch(url, options);
+                    if (!response.ok) {
+                        throw new Error(`HTTP ${response.status} - ${response.statusText}`);
+                    }
+                    return await response.json();
+                } catch (error) {
+                    return { "error": "fetch_failed", "message": error.message };
+                }
+            }
+        """, {"url": url, "extraHeaders": headers, "config": config})
+
+        return response
+    except Exception as e:
+        raise send_exception()
+
+def safe_goto(page, url, **kwargs):
+    caller = inspect.stack()[1]
+    log(f"[DEBUG] goto called from {caller.filename}:{caller.lineno} url={url}")
+    return page.goto(url, **kwargs)
