@@ -260,20 +260,31 @@ class TimeUtils:
 
     @staticmethod
     def get_dates_from_first_of_month_to_yesterday() -> List[str]:
-        """获取从本月第一天到昨天的日期列表"""
+        """获取从本月第一天到昨天的日期列表
+        如果今天是本月第一天，则返回上个月的日期列表
+        """
         today = datetime.today()
-        first_day_of_month = today.replace(day=1)
         yesterday = today - timedelta(days=1)
 
-        date_list = []
-        current_date = first_day_of_month
+        # 如果今天是本月第一天，取上个月
+        if today.day == 1:
+            # 找到上个月最后一天
+            last_month_last_day = today - timedelta(days=1)
+            # 上个月第一天
+            first_day_of_last_month = last_month_last_day.replace(day=1)
+            start_date = first_day_of_last_month
+            end_date = last_month_last_day
+        else:
+            start_date = today.replace(day=1)
+            end_date = yesterday
 
-        while current_date <= yesterday:
+        date_list = []
+        current_date = start_date
+        while current_date <= end_date:
             date_list.append(current_date.strftime('%Y-%m-%d'))
             current_date += timedelta(days=1)
 
         return date_list
-
     # ==================== 月份相关 ====================
 
     @staticmethod
